==> tine20-allinone_2020.08.8.tar.bz2: Addressbook/js/Addressbook-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ro_RO\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Date Contact Afaceri"

, "Organisation / Unit"
: "Organizaţa / Unitatea"

, "Business Address"
: "Addresă Afaceri"

, "Email"
: "Email"

, "Telephone Work"
: "Telefon Muncă"

, "Telephone Cellphone"
: "Telefon Celular"

, "Telephone Car"
: "Telefon Maşină"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Pagină Telefon"

, "URL"
: "URL"

, "Role"
: "Rol"

, "Room"
: "Camera"

, "Assistant"
: "Asistent"

, "Assistant Telephone"
: "Asistent Telefon"

, "Private Contact Data"
: "Date Contact Private"

, "Private Address"
: "Adresă Privată"

, "Email Home"
: "Email Acasă"

, "Telephone Home"
: "Telefon Acasă"

, "Telephone Cellphone Private"
: "Telefon Celular Privat"

, "Telephone Fax Home"
: "Telephone Fax Acasă"

, "URL Home"
: "URL Acasă"

, "Other Data"
: "Alte Date"

, "Birthday"
: "Data naşterii"

, "Job Title"
: "Titlu Job"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Listă"
 ,"Liste"
 ,"Liste"

]
, "Percent"
: ""

, "Description"
: "Descriere"

, "Members"
: ""

, "Type"
: "Tip"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  ""
 ,""
 ,""

]
, "Contact, Contacts"
: [
  "Contact"
 ,"Contacte"
 ,"Contacte"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "Ţara"

, "City"
: "Oraş"

, "Postalcode"
: "CodPoştal"

, "Region"
: "Regiune"

, "Street"
: "Strada"

, "Street 2"
: "Strada 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "Ţara (privată)"

, "City (private)"
: "Oraş (privat)"

, "Postalcode (private)"
: "Cod Poştal (privat)"

, "Region (private)"
: "Regiune (privată)"

, "Street (private)"
: "Strada (privată)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (privat)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""
 ,""
 ,""

]
, "Note"
: "Notă"

, "Last Name"
: "Nume"

, "Display Name"
: "Nume Afişat"

, "Full Name"
: "Nume Complet"

, "First Name"
: "Prenume"

, "Middle Name"
: ""

, "Title"
: ""

, "Suffix"
: "Sufix"

, "Company"
: "Compania"

, "Unit"
: "Unit"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "Rol Job"

, "Salutation"
: ""

, "syncBackendIds"
: ""

, "Car phone"
: "Telefon maşină"

, "Mobile"
: "Mobil"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (privat)"

, "Phone (private)"
: "Telefon (privat)"

, "Pager"
: "Pager"

, "Phone"
: "Telefon"

, "Timezone"
: ""

, "Web"
: "Web"

, "URL (private)"
: "URL (privat)"

, "Label"
: ""

, "Lists"
: "Liste"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "Informaţii Contact"

, "Company Address"
: "Adresă Companie"

, "New Contact"
: "Contact nou"

, "ID"
: ""

, "Name"
: "Nume"

, "Structure, Structures"
: [
  ""
 ,""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Import contacte"

, "Contact of a user account"
: "Contact al unui cont de utilizator"

, "No name"
: ""

, "Business"
: ""

, "Private"
: "Privat"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Taguri"

, "List Roles"
: ""

, "Street (Company Address)"
: "Strada (Adresă Companie)"

, "Street 2 (Company Address)"
: "Stradă 2 (Adresă Companie)"

, "City (Company Address)"
: "Oraş (Adresă Companie)"

, "Region (Company Address)"
: "Regiune (Adresă Companie)"

, "Postal Code (Company Address)"
: "Cod Poştal (Adresă Companie)"

, "Country (Company Address)"
: "Ţara (Adresă Companie)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Strada (Adresă privată)"

, "Street 2 (Private Address)"
: "Strada 2(Adresă privată) "

, "City (Private Address)"
: "Oraş (Adresă privată)"

, "Region (Private Address)"
: "Regiune (Adresă privată)"

, "Postal Code (Private Address)"
: "Cod Poştal (Adresă privată)"

, "Country (Private Address)"
: "Ţara (Adresă privată)"

, "Company Communication"
: "Comunicare Companie"

, "Private Communication"
: "Comunicare Privată"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privat)"

, "Web (private)"
: "Web (privat)"

, "Contacts"
: "Contacte"

, "Addressbooks"
: ""

, "User Account"
: "Cont utilizator"

, "Quick Search"
: ""

, "Postal Code"
: "Cod Poştal"

, "Last Modified Time"
: "Data ultima modificare"

, "Last Modified By"
: "Ultima modificare de"

, "Creation Time"
: "Data creare"

, "Created By"
: "Creat de"

, "Email Address, Email Addresses"
: [
  ""
 ,""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""
 ,""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "Introducere Descriere"

, "{0} must be given"
: ""

, "Member of List"
: "Membru al Listei"

, "Map"
: "Harta"

, "Company address"
: "Adresă Companie"

, "Private address"
: "Adresă privată"

, "CardDAV URL"
: "URL CardDAV "

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "Informaţii Personale"

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "Toate contactele"

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: "Configurare export Contacte ODS"

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: "Configurare export Contacte XLS"

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "implicit"

, "All Contacts"
: "Toate contactele"

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Dl"

, "Ms"
: "Dna"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Import Contact VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Import Contact CSV din  Outlook address book"

, "Contact CSV import from mac address book"
: "Import Contact CSV din mac address book"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Import Contact din Google address book"

, "manage shared addressbooks"
: ""

, "Create new shared addressbook folders"
: ""

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""

]
, "%s's personal addressbook"
: ""

, "All contacts I have read grants for"
: ""

, "My company"
: "Compania mea"

, "All coworkers in my company"
: "Toţi colegii din compania mea"

, "My contacts"
: "Contactele mele"

, "All contacts in my Addressbooks"
: "Toate contactele din my Addressbooks"

, "Last modified by me"
: "Ultima modificată de mine"

, "All contacts that I have last modified"
: "Toate contactele pe care le-am modificat ultima data"

, "Internal Contacts"
: "Contacte Interne"

, "List"
: "Listă"

, "Addressbook"
: ""

, "Contact"
: "Contact"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "Harta"

, "Preferred Address"
: ""

, "Personal Information"
: "Informaţii Personale"

, "Salutation"
: ""

, "Title"
: ""

, "Short Name"
: ""

, "First Name"
: "Prenume"

, "Middle Name"
: ""

, "Last Name"
: "Nume"

, "Company"
: "Compania"

, "Unit"
: "Unit"

, "Display Name"
: "Nume Afişat"

, "Industry, Industries"
: [
  ""
 ,""
 ,""

]
, "Job Title"
: "Titlu Job"

, "Birthday (private)"
: ""

, "Contact Information"
: "Informaţii Contact"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefon (privat)"

, "Mobile (private)"
: "Mobil (privat)"

, "Fax (private)"
: "Fax (privat)"

, "E-Mail"
: "E-Mail"

, "E-Mail (private)"
: "E-Mail (privat)"

, "Web"
: "Web"

, "Company Address"
: "Adresă Companie"

, "Street"
: "Strada"

, "Street 2"
: "Strada 2"

, "Region"
: "Regiune"

, "Postal Code"
: "Cod Poştal"

, "City"
: "Oraş"

, "Country"
: "Ţara"

, "Private Address"
: "Adresă Privată"

, "Description"
: "Descriere"

, "Enter description"
: "Introducere Descriere"

, "Groups"
: ""

, "Parse address"
: ""

, "Print contact"
: ""

, "Paste address"
: ""

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "Contact"
 ,"Contacte"
 ,"Contacte"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "URL CardDAV "

, "New Contact"
: "Contact nou"

, "Addressbook, Addressbooks"
: [
  ""
 ,""
 ,""

]
, "ID"
: ""

, "Name"
: "Nume"

, "Structure, Structures"
: [
  ""
 ,""
 ,""

]
, "Resources"
: ""

, "Private"
: "Privat"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""
 ,""
 ,""

]
, "List Personal Grant, List Personal Grants"
: [
  ""
 ,""
 ,""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "Sufix"

, "Birthday"
: "Data naşterii"

, "Job Role"
: "Rol Job"

, "Room"
: "Camera"

, "Street (Company Address)"
: "Strada (Adresă Companie)"

, "Street 2 (Company Address)"
: "Stradă 2 (Adresă Companie)"

, "City (Company Address)"
: "Oraş (Adresă Companie)"

, "Region (Company Address)"
: "Regiune (Adresă Companie)"

, "Postal Code (Company Address)"
: "Cod Poştal (Adresă Companie)"

, "Country (Company Address)"
: "Ţara (Adresă Companie)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Strada (Adresă privată)"

, "Street 2 (Private Address)"
: "Strada 2(Adresă privată) "

, "City (Private Address)"
: "Oraş (Adresă privată)"

, "Region (Private Address)"
: "Regiune (Adresă privată)"

, "Postal Code (Private Address)"
: "Cod Poştal (Adresă privată)"

, "Country (Private Address)"
: "Ţara (Adresă privată)"

, "Company Communication"
: "Comunicare Companie"

, "Private Communication"
: "Comunicare Privată"

, "Web (private)"
: "Web (privat)"

, "Contacts"
: "Contacte"

, "Addressbooks"
: ""

, "User Account"
: "Cont utilizator"

, "Quick Search"
: ""

, "Type"
: "Tip"

, "Last Modified Time"
: "Data ultima modificare"

, "Last Modified By"
: "Ultima modificare de"

, "Creation Time"
: "Data creare"

, "Created By"
: "Creat de"

, "List, Lists"
: [
  "Listă"
 ,"Liste"
 ,"Liste"

]
, "Lists"
: "Liste"

, "Email Address, Email Addresses"
: [
  ""
 ,""
 ,""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""
 ,""
 ,""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "Import contacte"

, "Contact of a user account"
: "Contact al unui cont de utilizator"

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Taguri"

, "Full Name"
: "Nume Complet"

, "Postalcode"
: "CodPoştal"

, "Street (private)"
: "Strada (privată)"

, "City (private)"
: "Oraş (privat)"

, "Region (private)"
: "Regiune (privată)"

, "Postalcode (private)"
: "Cod Poştal (privat)"

, "Country (private)"
: "Ţara (privată)"

, "Email"
: "Email"

, "Car phone"
: "Telefon maşină"

, "Pager"
: "Pager"

, "Email (private)"
: "Email (privat)"

, "URL (private)"
: "URL (privat)"

, "Note"
: "Notă"

, "Timezone"
: ""

, "Geo"
: "Geo"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "Adresă Companie"

, "Private address"
: "Adresă privată"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "Toate contactele"

, "Default Addressbook"
: ""

, "The default addressbook for new contacts"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on addressbook startup"
: ""

, "Contacts ODS export configuration"
: "Configurare export Contacte ODS"

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: "Configurare export Contacte XLS"

, "Use this configuration for the contact XLS export."
: ""

, "default"
: "implicit"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: ""

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: ""

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: ""

, "Mr"
: "Dl"

, "Ms"
: "Dna"

, "Parsing rules for addresses"
: ""

, "Path to a XML file with address parsing rules."
: ""

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: ""

, "Business Contact Data"
: "Date Contact Afaceri"

, "Organisation / Unit"
: "Organizaţa / Unitatea"

, "Business Address"
: "Addresă Afaceri"

, "Telephone Work"
: "Telefon Muncă"

, "Telephone Cellphone"
: "Telefon Celular"

, "Telephone Car"
: "Telefon Maşină"

, "Telephone Fax"
: "Telefon Fax"

, "Telephone Page"
: "Pagină Telefon"

, "URL"
: "URL"

, "Role"
: "Rol"

, "Assistant"
: "Asistent"

, "Assistant Telephone"
: "Asistent Telefon"

, "Private Contact Data"
: "Date Contact Private"

, "Email Home"
: "Email Acasă"

, "Telephone Home"
: "Telefon Acasă"

, "Telephone Cellphone Private"
: "Telefon Celular Privat"

, "Telephone Fax Home"
: "Telephone Fax Acasă"

, "URL Home"
: "URL Acasă"

, "Other Data"
: "Alte Date"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Import Contact CSV din  Outlook address book"

, "Contact CSV import from mac address book"
: "Import Contact CSV din mac address book"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: ""

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Import Contact VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Import Contact din Google address book"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "Contacte Interne"

, "All contacts I have read grants for"
: ""

, "My company"
: "Compania mea"

, "All coworkers in my company"
: "Toţi colegii din compania mea"

, "My contacts"
: "Contactele mele"

, "All contacts in my Addressbooks"
: "Toate contactele din my Addressbooks"

, "Last modified by me"
: "Ultima modificată de mine"

, "All contacts that I have last modified"
: "Toate contactele pe care le-am modificat ultima data"

, "All Contacts"
: "Toate contactele"

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: ""

, "Create new shared addressbook folders"
: ""

, "manage shared addressbook favorites"
: ""

, "Create or update shared addressbook favorites"
: ""

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""


]
, "Industry"
: ""

, "Contact"
: "Contact"

, "Addressbook"
: ""

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "Listă"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
